/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/


/*! \file atomic.h
 * \brief Atomic blocks */

#ifndef SRC_XMC1100_ATOMIC_ATOMIC_H_
#define SRC_XMC1100_ATOMIC_ATOMIC_H_

#include <stdint.h>
#include <cmsis_gcc.h>

extern uint32_t __atomic_int_flag;

/*! \brief save interrupts enable state and disable interrupts */
static inline void atomic_enter(void)
{
	__atomic_int_flag = __get_PRIMASK();
	__disable_irq();
}


/*! \brief restore interrupts enable state */
static inline void atomic_exit(void)
{
	if (!__atomic_int_flag) {
		__enable_irq();
	}
}


#endif /* SRC_XMC1100_ATOMIC_ATOMIC_H_ */
