/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/

#include "flash_storage.h"
#include "xmc_flash.h"
#include "conf_flash_storage.h"

#define _STORAGE_ADDR	BASE_ADDR_SECTOR(CONF_FLASH_STORAGE_SECTOR)

void FLASH_erase_stored_data(void)
{
	// clear err flag
	XMC_FLASH_ClearStatus();
	// erase page
	XMC_FLASH_ErasePages(_STORAGE_ADDR, 1);
}

/* Erase the first page of the configured sector
 * (see 'conf_flash_storage.h') and write the data
 * to it
 * */
void FLASH_store(uint32_t *to_store, uint32_t size)
{
	uint32_t buffer[64]; // size of a page
	uint16_t i;

	// clear err flag
	XMC_FLASH_ClearStatus();
	// erase page
	XMC_FLASH_ErasePages(_STORAGE_ADDR, 1);
	// copy data to buffer
	for (i = 0; i < size; i++)
		((uint8_t*)buffer)[i] = ((uint8_t*)to_store)[i];
	// pad with zeros
	for (i = size; i < 256; i++)
		((uint8_t*)buffer)[i] = 0;
	// write data to flash
	XMC_FLASH_WriteBlocks(_STORAGE_ADDR, buffer, XMC_FLASH_BLOCKS_PER_PAGE, false);
}

/* Load the data from flash
 * */
void FLASH_load(uint32_t *to_load, uint32_t size)
{
	uint16_t i;

	for(i = 0; i < size; i++)
		((uint8_t*)to_load)[i] = ((uint8_t*)(_STORAGE_ADDR))[i];
}
