/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/


#include "gpio.h"
#include "xmc_gpio.h"
#include "xmc1_gpio_map.h"
#include "xmc1_gpio.h"
#include "src/xmc1100/i2c/conf_i2c.h"
#include "src/xmc1100/i2c/i2c.h"
#include "src/xmc1100/time/time.h"


#define TLx_SUPPLY_PIN  P1_0
#define TLI_SUPPLY_PIN  P0_15
#define ADDR_PIN 	CONF_I2C_SDA_PIN
#define SCL_PIN 	CONF_I2C_SCL_PIN

static XMC_GPIO_CONFIG_t cfg = {0};

void GPIO_sensor_supply(bool on)
{
	/* Disable interrupts:
	 * Disabling and enabling the sensor power will also
	 * disable and enable the I2C bus SDA and SCL pull-ups
	 * which will drive the SDA/SCL lines low or high.
	 * This will cause an interrupt request if interrupts
	 * are enabled.
	 * Note that XMC1100 does not support pull-up resistances
	 * on pin while the pin is set to open-drain output
	 * */
	NVIC_DisableIRQ(ERU0_0_IRQn);
	if (on) {
		cfg.mode = XMC_GPIO_MODE_OUTPUT_PUSH_PULL;

		// enable power for sensor
		cfg.output_level = XMC_GPIO_OUTPUT_LEVEL_HIGH;
		XMC_GPIO_Init(TLx_SUPPLY_PIN, &cfg);

		cfg.output_level = XMC_GPIO_OUTPUT_LEVEL_LOW;
		XMC_GPIO_Init(TLI_SUPPLY_PIN, &cfg);

		wait(2);
	} else {
		cfg.mode = XMC_GPIO_MODE_OUTPUT_PUSH_PULL,

		cfg.output_level = XMC_GPIO_OUTPUT_LEVEL_LOW;
		XMC_GPIO_Init(TLx_SUPPLY_PIN, &cfg);

		cfg.output_level = XMC_GPIO_OUTPUT_LEVEL_HIGH;
		XMC_GPIO_Init(TLI_SUPPLY_PIN, &cfg);

		// delay for 200us
		wait(5000 - 2);
	}
}


void GPIO_set_addr_wait(bool high)
{
	XMC_GPIO_CONFIG_t cfg = {0};

	if (high) {
		// wait for ~200.2us
		wait(200 - 2);
	} else {
		// set output level to LOW
		/* Using XMC_GPIO_Init would cause the
		 * line voltage to turn HIGH briefly,
		 * determining an erroneous startup sequence */
		XMC_GPIO_PORT2->OMR = (uint32_t)XMC_GPIO_OUTPUT_LEVEL_LOW << 10;
		XMC_GPIO_PORT2->IOCR[2] |= (uint32_t)XMC_GPIO_MODE_OUTPUT_PUSH_PULL << 16;
		// wait for >200us
		wait(300 - 2);
		// set output level to HIGH
		cfg.output_level = XMC_GPIO_OUTPUT_LEVEL_HIGH;
		XMC_GPIO_Init(ADDR_PIN, &cfg);
		// wait for a stable voltage
		wait(100);
		// reconfigure SDA pin as ALT-output
		I2C_mode_gpio_input();
	}
}
