/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/

/*! \file gpio.h
 *  \brief GPIO based functions for controlling the power supply and ADDR pin state of the sensor. */


#ifndef SRC_XMC1100_GPIO_GPIO_H_
#define SRC_XMC1100_GPIO_GPIO_H_

#include <stdbool.h>

/*! \brief Set the sensor supply voltage and the discrete I2C bus
 * pull-up resistors voltage HIGH or LOW */
void GPIO_sensor_supply(bool on);

/*! \brief Configure the ADDR pin logical level at startup.
 *
 * (Necessary for TLV493D-A1B6 sensor only!)
 * Set the ADDR(SDA) I2C pin HIGH or LOW and wait for
 * the sensor startup. Finally, set ADDR to HIGH.
 * Must be called right after the sensor power-up. */
void GPIO_set_addr_wait(bool high);

#endif /* SRC_XMC1100_GPIO_GPIO_H_ */
