/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/

#include "time.h"
#include <XMC1100.h>
#include "core_cm0.h"


/* Defines for SysTick */
// multiplication factor for 1us resolution
#define _MULTIPLICATION_FACTOR			(32u)
//systick stop value
#define _SYSTICK_CTRL_DISABLE_Msk		(0UL << SysTick_CTRL_ENABLE_Pos)


/* Delay for 'time_us' us + t_call + t_cfg
 * t_call ~= 1.2us
 * t_cfg  ~= 1us
 *
 * As such, the actual delay time will be time_us + 2.2us
 *
 * Should support values up to 67s
 * */
void wait(uint32_t time_us)
{
	// sanity check
	if (!time_us) {
		return;
	}
	SysTick->LOAD  = (uint32_t)((time_us * _MULTIPLICATION_FACTOR) - 1UL);
	SysTick->VAL   = 0UL;
	SysTick->CTRL  = SysTick_CTRL_CLKSOURCE_Msk | SysTick_CTRL_ENABLE_Msk;
	while((SysTick->CTRL & 0x10000) == 0UL) {
	}
	SysTick->CTRL=_SYSTICK_CTRL_DISABLE_Msk;
}
                                                      
