/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/

/*!
 * \file conf_uart.h
 * \brief Configure UART pins and communication parameters. */

#ifndef SRC_PERIPHERALS_UART_CONF_UART_H_
#define SRC_PERIPHERALS_UART_CONF_UART_H_

#include <xmc_usic.h>
#include <xmc_uart.h>
#include <xmc_gpio.h>


/*! \brief define USIC module and channel used for UART */
#define CONF_UART_CH			XMC_UART0_CH0

/*! \brief Pin used for UART RX */
#define CONF_UART_RX_PIN 		P2_2

/*! \brief Pin used for UART TX */
#define CONF_UART_TX_PIN 		P2_1


/* UART RX pin (pin 2.2) configuration */
static const XMC_GPIO_CONFIG_t UART_RX_PIN_CONFIG =
{
  .mode = XMC_GPIO_MODE_INPUT_TRISTATE,
  .input_hysteresis = XMC_GPIO_INPUT_HYSTERESIS_STANDARD
};

/* UART TX pin (pin 2.1) configuration */
static const XMC_GPIO_CONFIG_t UART_TX_PIN_CONFIG =
{
  .mode = XMC_GPIO_MODE_OUTPUT_PUSH_PULL_ALT6,
  .input_hysteresis = XMC_GPIO_INPUT_HYSTERESIS_STANDARD
};

/* UART channel configuration */
static const XMC_UART_CH_CONFIG_t UART_CHANNEL_CONFIG =
{
  .baudrate      = 115200U,
  .data_bits     = 8U,
  .frame_length  = 8U,
  .stop_bits     = 1U,
  .oversampling  = 16U,
  .parity_mode   = XMC_USIC_CH_PARITY_MODE_NONE
};

#endif /* SRC_PERIPHERALS_UART_CONF_UART_H_ */
