/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/


#include "conf_uart.h"
#include "uart.h"
#include <xmc_uart.h>

/////////////////////////////////////////////////////
// 					  INTERNALS
/////////////////////////////////////////////////////


void UART_init(void)
{
	/* Initialize USIC channel in UART mode*/
	XMC_UART_CH_Init(XMC_UART0_CH0, &UART_CHANNEL_CONFIG);
	/*Set input source path*/
	XMC_USIC_CH_SetInputSource(XMC_UART0_CH0, XMC_USIC_CH_INPUT_DX0, 6U);
	//XMC_USIC_CH_SetInputSource(XMC_UART0_CH0, XMC_USIC_CH_INPUT_DX3, 0U);
	//XMC_USIC_CH_SetInputSource(XMC_UART0_CH0, XMC_USIC_CH_INPUT_DX5, 0U);
	/*Configure transmit FIFO*/
	XMC_USIC_CH_TXFIFO_Configure(XMC_UART0_CH0, 16U,
			XMC_USIC_CH_FIFO_SIZE_16WORDS, 1U);
	/*Configure receive FIFO*/
	XMC_USIC_CH_RXFIFO_Configure(XMC_UART0_CH0, 0U,
			XMC_USIC_CH_FIFO_SIZE_16WORDS, 15U);
	/* Start UART */
	XMC_UART_CH_Start(XMC_UART0_CH0);
	/*Set service request for UART protocol events*/
	XMC_USIC_CH_SetInterruptNodePointer(XMC_UART0_CH0,
			XMC_USIC_CH_INTERRUPT_NODE_POINTER_PROTOCOL, 0U);
	/*Set service request for tx FIFO transmit interrupt*/
	XMC_USIC_CH_TXFIFO_SetInterruptNodePointer(XMC_UART0_CH0,
			XMC_USIC_CH_TXFIFO_INTERRUPT_NODE_POINTER_STANDARD, 1U);

	/* enable the I/O pins
	 * (this can later be isolated to create an
	 * enable/disable mechanism)
	 * */
	XMC_GPIO_Init(CONF_UART_TX_PIN, &UART_TX_PIN_CONFIG);
	XMC_GPIO_Init(CONF_UART_RX_PIN, &UART_RX_PIN_CONFIG);
}

void UART_read(uint8_t *data, uint32_t count)
{
	uint32_t i;

	// sanity check
	if ((data != NULL) && (count > 0U)) {
		// read data
		for (i = 0U; i < count; i++) {
			// wait for item in FIFO
			while (XMC_USIC_CH_RXFIFO_IsEmpty(XMC_UART0_CH0))
				;
			data[i] = (uint8_t) XMC_UART_CH_GetReceivedData(XMC_UART0_CH0);
		}
	}
}

uint8_t UART_read_byte(void)
{
	return XMC_UART_CH_GetReceivedData(XMC_UART0_CH0);
}


uint8_t UART_available(void)
{
	// return number of bytes available for reading
	return XMC_USIC_CH_RXFIFO_GetLevel(XMC_UART0_CH0);
}

void UART_write(void *data, uint32_t count)
{
	uint32_t i;
	uint8_t *_data;
	//volatile uint32_t _delay;

	_data = data;
	// iterate data
	for (i = 0U; i < count; i++) {
		// wait if TX FIFO full
		while (XMC_USIC_CH_TXFIFO_IsFull(CONF_UART_CH))
				;
//		for (_delay = 0; _delay < 200000; _delay ++)
//			;
		XMC_UART_CH_Transmit(CONF_UART_CH, (uint16_t) _data[i]);
	}
}

void UART_clear_rx_fifo(void)
{
	XMC_USIC_CH_RXFIFO_Flush(XMC_UART0_CH0);
}
