/*
*****************************************************************************
* Copyright (C) 2019 Infineon Technologies AG. All rights reserved.
*
* Infineon Technologies AG (INFINEON) is supplying this file for use
* exclusively with Infineon's products. This file can be freely
* distributed within development tools and software supporting such microcontroller
* products.
*
* THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
* OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
* INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR DIRECT, INDIRECT, INCIDENTAL,
* ASPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
*
******************************************************************************
*/

/*! \file uart.h
 * \brief UART Driver for XMC1100 USIC Module */

#ifndef SRC_PERIPHERALS_UART_UART_H_
#define SRC_PERIPHERALS_UART_UART_H_

#include <stdint.h>
#include <stdbool.h>



/*! \brief Initialize the UART peripheral */
void UART_init(void);

/*! \brief Return number of bytes available for reading */
uint8_t UART_available(void);

/*! \brief Read count bytes to the data array. If not enough
 * bytes available, will block until available. */
void UART_read(uint8_t *data, uint32_t count);

/*! \brief Read last received data byte. Not blocking */
uint8_t UART_read_byte(void);

/*! \brief Discard all data from the receive FIFO buffer */
void UART_clear_rx_fifo(void);

/*! \brief Write count bytes from the data array to UART */
void UART_write(void *data, uint32_t count);

#endif /* SRC_PERIPHERALS_UART_UART_H_ */
